@@ -1,5 +1,5 @@
 /* Reverse Engineer's Hex Editor
- * Copyright (C) 2019-2024 Daniel Collins <solemnwarning@solemnwarning.net>
+ * Copyright (C) 2019-2025 Daniel Collins <solemnwarning@solemnwarning.net>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published by
@@ -44,6 +44,7 @@ enum {
 	ID_EDIT_COMMENT = 1,
 	ID_COPY_COMMENT,
 	ID_GOTO,
+	ID_GOTO_END,
 	ID_SELECT,
 	ID_FILTER_TEXT,
 	ID_REFRESH_TIMER,
@@ -126,6 +127,16 @@ std::string REHex::CommentTree::name() const
 	return "CommentTree";
 }
 
+std::string REHex::CommentTree::label() const
+{
+	return "Comments";
+}
+
+REHex::ToolPanel::Shape REHex::CommentTree::shape() const
+{
+	return ToolPanel::TPS_TALL;
+}
+
 void REHex::CommentTree::save_state(wxConfig *config) const
 {
 	/* No state to save. */
@@ -277,7 +288,10 @@ void REHex::CommentTree::OnContextMenu(wxDataViewEvent &event)
 	
 	wxMenu menu;
 	
-	menu.Append(ID_GOTO, "&Jump to offset");
+	menu.Append(ID_GOTO, "&Jump to start");
+	
+	menu.Append(ID_GOTO_END, "Jump &to end");
+	menu.Enable(ID_GOTO_END, (key->length > BitOffset::ZERO));
 	
 	menu.Append(ID_SELECT, "&Select bytes");
 	menu.Enable(ID_SELECT, (key->length > 0));
@@ -302,9 +316,20 @@ void REHex::CommentTree::OnContextMenu(wxDataViewEvent &event)
 				
 				break;
 				
+			case ID_GOTO_END:
+			{
+				DocumentCtrl::GenericDataRegion *end_dr = document_ctrl->data_region_by_offset(key->offset + key->length - BitOffset(0, 1));
+				if(end_dr != NULL)
+				{
+					document->set_cursor_position(end_dr->last_row_nearest_column(INT_MAX));
+				}
+				
+				break;
+			}
+				
 			case ID_SELECT:
 				document->set_cursor_position(key->offset);
-				document_ctrl->set_selection_raw(key->offset, (key->offset + key->length - 1));
+				document_ctrl->set_selection_raw(key->offset, (key->offset + key->length - BitOffset(0, 1)));
 				
 				CallAfter([this]()
 				{
