@@ -1,5 +1,5 @@
 /* Reverse Engineer's Hex Editor
- * Copyright (C) 2017-2024 Daniel Collins <solemnwarning@solemnwarning.net>
+ * Copyright (C) 2017-2025 Daniel Collins <solemnwarning@solemnwarning.net>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published by
@@ -36,6 +36,7 @@
 #include "CharacterFinder.hpp"
 #include "document.hpp"
 #include "Events.hpp"
+#include "FontCharacterCache.hpp"
 #include "LRUCache.hpp"
 #include "NestedOffsetLengthMap.hpp"
 #include "Palette.hpp"
@@ -91,6 +92,11 @@ namespace REHex {
 					
 					virtual unsigned int check();
 					
+					/**
+					 * @brief Get the first and last ["indent"] offset visible on a specific line.
+					*/
+					virtual std::pair<BitOffset, BitOffset> indent_offset_at_y(DocumentCtrl &doc_ctrl, int64_t y_lines_rel) = 0;
+					
 				protected:
 					Region(BitOffset indent_offset, BitOffset indent_length);
 					
@@ -136,9 +142,9 @@ namespace REHex {
 						NoHighlight(): Highlight() {}
 					};
 					
-					static void draw_hex_line(DocumentCtrl *doc_ctrl, wxDC &dc, int x, int y, const unsigned char *data, size_t data_len, unsigned int pad_bytes, BitOffset base_off, bool alternate_row, const std::function<Highlight(BitOffset)> &highlight_at_off, bool is_last_line);
-					static void draw_ascii_line(DocumentCtrl *doc_ctrl, wxDC &dc, int x, int y, const unsigned char *data, size_t data_len, size_t data_extra_pre, size_t data_extra_post, unsigned int pad_bytes, BitOffset base_off, bool alternate_row, const std::function<Highlight(BitOffset)> &highlight_at_off, bool is_last_line);
-					static void draw_bin_line(DocumentCtrl *doc_ctrl, wxDC &dc, int x, int y, const std::vector<bool> &data, BitOffset data_len, unsigned int pad_bytes, BitOffset base_off, bool alternate_row, const std::function<Highlight(BitOffset)> &highlight_at_off, bool is_last_line);
+					static void draw_hex_line(DocumentCtrl *doc_ctrl, wxDC &dc, int x, int y, const unsigned char *data, size_t data_len, unsigned int pad_bytes, BitOffset base_off, bool alternate_row, bool has_focus, bool view_active, const std::function<Highlight(BitOffset)> &highlight_at_off, bool is_last_line);
+					static void draw_ascii_line(DocumentCtrl *doc_ctrl, wxDC &dc, int x, int y, const unsigned char *data, size_t data_len, size_t data_extra_pre, size_t data_extra_post, unsigned int pad_bytes, BitOffset base_off, bool alternate_row, bool has_focus, bool view_active, const std::function<Highlight(BitOffset)> &highlight_at_off, bool is_last_line);
+					static void draw_bin_line(DocumentCtrl *doc_ctrl, wxDC &dc, int x, int y, const std::vector<bool> &data, BitOffset data_len, unsigned int pad_bytes, BitOffset base_off, bool alternate_row, bool has_focus, bool view_active, const std::function<Highlight(BitOffset)> &highlight_at_off, bool is_last_line);
 					
 					/**
 					 * @brief Calculate offset of byte at X co-ordinate.
@@ -315,6 +321,8 @@ namespace REHex {
 					 * will be invoked.
 					*/
 					virtual bool OnPaste(DocumentCtrl *doc_ctrl);
+					
+					virtual std::pair<BitOffset, BitOffset> indent_offset_at_y(DocumentCtrl &doc_ctrl, int64_t y_lines_rel) override;
 			};
 			
 			class DataRegion: public GenericDataRegion
@@ -395,22 +403,12 @@ namespace REHex {
 				virtual void calc_height(REHex::DocumentCtrl &doc) override;
 				virtual void draw(REHex::DocumentCtrl &doc, wxDC &dc, int x, int64_t y) override;
 				virtual wxCursor cursor_for_point(REHex::DocumentCtrl &doc, int x, int64_t y_lines, int y_px) override;
+				virtual std::pair<BitOffset, BitOffset> indent_offset_at_y(DocumentCtrl &doc_ctrl, int64_t y_lines_rel) override;
 				
 				CommentRegion(BitOffset c_offset, BitOffset c_length, const wxString &c_text, bool truncate, BitOffset indent_offset, BitOffset indent_length);
 				
 				friend DocumentCtrl;
 			};
-
-			struct AlignedCharacter
-			{
-				wxString wx_char;
-				ucs4_t unicode_char;
-				wxSize char_size;
-				int column;
-
-				AlignedCharacter(wxString wx_char, ucs4_t unicode_char, wxSize char_size, int column) :
-					wx_char(wx_char), unicode_char(unicode_char), char_size(char_size), column(column) {}
-			};
 			
 			DocumentCtrl(wxWindow *parent, SharedDocumentPointer &doc, long style = 0);
 			~DocumentCtrl();
@@ -449,6 +447,7 @@ namespace REHex {
 			bool special_view_active() const;
 			
 			void set_cursor_position(BitOffset position, Document::CursorState cursor_state = Document::CSTATE_GOTO);
+			bool check_cursor_position(BitOffset position);
 			
 			bool has_prev_cursor_position() const;
 			void goto_prev_cursor_position();
@@ -522,6 +521,8 @@ namespace REHex {
 			GenericDataRegion *data_region_by_offset(BitOffset offset);
 			std::vector<Region*>::iterator region_by_y_offset(int64_t y_offset);
 			
+			std::pair<BitOffset, BitOffset> get_indent_offset_at_line(int64_t line);
+			
 			/**
 			 * @brief Compare two offsets in the address space defined by the regions.
 			 *
@@ -589,11 +590,26 @@ namespace REHex {
 			
 			wxFont &get_font();
 			
+			/**
+			 * @brief Get the FontCharacterCache object for this DocumentCtrl.
+			 *
+			 * DocumentCtrl maintains a FontCharacterCache instance for the hex font
+			 * for use by any regions within it, returned object reference will remain
+			 * valid until the DocumentCtrl is destroyed.
+			*/
+			const FontCharacterCache &get_fcc() const;
+			
 			/**
 			 * @brief Returns the current vertical scroll position, in lines.
 			*/
 			int64_t get_scroll_yoff() const;
 			
+			int64_t get_scroll_yoff_max() const;
+			
+			unsigned int get_visible_lines() const;
+			
+			int64_t get_total_lines() const;
+			
 			/**
 			 * @brief Set the vertical scroll position, in lines.
 			*/
@@ -615,10 +631,9 @@ namespace REHex {
 			void OnClearHighlight(wxCommandEvent &event);
 			void OnIdle(wxIdleEvent &event);
 			void OnFontSizeAdjustmentChanged(FontSizeAdjustmentEvent &event);
+			void OnFocus(wxFocusEvent& event);
 			
-		#ifndef UNIT_TEST
 		private:
-		#endif
 			friend DataRegion;
 			friend CommentRegion;
 			
@@ -639,9 +654,7 @@ namespace REHex {
 			
 			/* Fixed-width font used for drawing hex data. */
 			wxFont hex_font;
-			
-			/* Size of a character in hex_font. */
-			unsigned char hf_height;
+			FontCharacterCache hex_font_cache;
 			
 			/* Size of the client area in pixels. */
 			int client_width;
@@ -695,7 +708,8 @@ namespace REHex {
 			
 			GenericDataRegion::ScreenArea mouse_down_area;
 			BitOffset mouse_down_at_offset;
-			int mouse_down_at_x;
+			int mouse_down_at_x, mouse_down_at_y;
+			bool mouse_selecting;
 			wxTimer mouse_select_timer;
 			BitOffset mouse_shift_initial;
 			
@@ -771,74 +785,6 @@ namespace REHex {
 			
 			void linked_scroll_visit_others(const std::function<void(DocumentCtrl*)> &func);
 			
-			static const int PRECOMP_HF_STRING_WIDTH_TO = 512;
-			unsigned int hf_string_width_precomp[PRECOMP_HF_STRING_WIDTH_TO];
-			
-			static const size_t GETTEXTEXTENT_CACHE_SIZE = 4096;
-			LRUCache<ucs4_t, wxSize> hf_gte_cache;
-
-#ifdef REHEX_CACHE_CHARACTER_BITMAPS
-			static const size_t HF_CHAR_BITMAP_CACHE_SIZE = 8192;
-			LRUCache<std::tuple<ucs4_t, unsigned int, unsigned int>, wxBitmap> hf_char_bitmap_cache;
-#endif
-
-#ifdef REHEX_CACHE_STRING_BITMAPS
-			struct StringBitmapCacheKey
-			{
-				int base_col;
-				std::vector<AlignedCharacter> characters;
-				unsigned int packed_fg_colour;
-				unsigned int packed_bg_colour;
-
-				StringBitmapCacheKey(int base_col, std::vector<AlignedCharacter> characters, unsigned int packed_fg_colour, unsigned int packed_bg_colour):
-					base_col(base_col), characters(characters), packed_fg_colour(packed_fg_colour), packed_bg_colour(packed_bg_colour) {}
-
-				bool operator<(const StringBitmapCacheKey &rhs) const
-				{
-					if(base_col != rhs.base_col)
-					{
-						return base_col < rhs.base_col;
-					}
-					
-					for(size_t i = 0;; ++i)
-					{
-						if(i < characters.size() && i < rhs.characters.size())
-						{
-							if(characters[i].unicode_char != rhs.characters[i].unicode_char)
-							{
-								return characters[i].unicode_char < rhs.characters[i].unicode_char;
-							}
-							else if(characters[i].column != rhs.characters[i].column)
-							{
-								return characters[i].column < rhs.characters[i].column;
-							}
-						}
-						else if(i < characters.size())
-						{
-							return false;
-						}
-						else if(i < rhs.characters.size())
-						{
-							return true;
-						}
-						else {
-							break;
-						}
-					}
-
-					if(packed_fg_colour != rhs.packed_fg_colour)
-					{
-						return packed_fg_colour < rhs.packed_fg_colour;
-					}
-
-					return packed_bg_colour < rhs.packed_bg_colour;
-				}
-			};
-
-			static const size_t HF_STRING_BITMAP_CACHE_SIZE = 256;
-			LRUCache<StringBitmapCacheKey, wxBitmap> hf_string_bitmap_cache;
-#endif
-			
 		public:
 			static std::list<wxString> wrap_text(const wxString &text, unsigned int cols);
 			static int wrap_text_height(const wxString &text, unsigned int cols);
@@ -849,19 +795,6 @@ namespace REHex {
 			BitOffset get_end_virt_offset() const;
 			bool is_selection_hidden() const;
 			
-			int hf_char_width();
-			int hf_char_height();
-			int hf_string_width(int length);
-			int hf_char_at_x(int x_px);
-
-#ifdef REHEX_CACHE_CHARACTER_BITMAPS
-			wxBitmap hf_char_bitmap(const wxString &wx_char, ucs4_t unicode_char, const wxSize &char_size, const wxColour &foreground_colour, const wxColour &background_colour);
-#endif
-
-#ifdef REHEX_CACHE_STRING_BITMAPS
-			wxBitmap hf_string_bitmap(const std::vector<AlignedCharacter> &characters, int base_col, const wxColour &foreground_colour, const wxColour &background_colour);
-#endif
-			
 			/* Stays at the bottom because it changes the protection... */
 			DECLARE_EVENT_TABLE()
 	};
