@@ -1,5 +1,5 @@
 /* Reverse Engineer's Hex Editor
- * Copyright (C) 2020 Daniel Collins <solemnwarning@solemnwarning.net>
+ * Copyright (C) 2020-2024 Daniel Collins <solemnwarning@solemnwarning.net>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published by
@@ -20,14 +20,14 @@
 #include "EditCommentDialog.hpp"
 #include "textentrydialog.hpp"
 
-void REHex::EditCommentDialog::run_modal(wxWindow *parent, Document *doc, off_t offset, off_t length)
+void REHex::EditCommentDialog::run_modal(wxWindow *parent, Document *doc, BitOffset offset, BitOffset length)
 {
-	const ByteRangeTree<Document::Comment> &comments = doc->get_comments();
-	auto old_comment = comments.find(ByteRangeTreeKey(offset, length));
+	const BitRangeTree<Document::Comment> &comments = doc->get_comments();
+	auto old_comment = comments.find(BitRangeTreeKey(offset, length));
 	
 	wxString old_comment_text = old_comment != comments.end()
 		? *(old_comment->second.text)
-		: "";
+		: wxString("");
 	
 	REHex::TextEntryDialog te(parent, "Enter comment", old_comment_text);
 	
