@@ -1,5 +1,5 @@
 /* Reverse Engineer's Hex Editor
- * Copyright (C) 2020-2023 Daniel Collins <solemnwarning@solemnwarning.net>
+ * Copyright (C) 2020-2025 Daniel Collins <solemnwarning@solemnwarning.net>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published by
@@ -22,6 +22,7 @@
 #include <condition_variable>
 #include <list>
 #include <mutex>
+#include <queue>
 #include <stddef.h>
 #include <thread>
 #include <wx/animate.h>
@@ -39,6 +40,7 @@
 #include "CharacterEncoder.hpp"
 #include "document.hpp"
 #include "Events.hpp"
+#include "RangeProcessor.hpp"
 #include "SafeWindowPointer.hpp"
 #include "SharedDocumentPointer.hpp"
 #include "ToolPanel.hpp"
@@ -56,13 +58,34 @@ namespace REHex {
 					virtual wxString OnGetItemText(long item, long column) const override;
 			};
 			
+			/**
+			 * @brief Batch of strings detected/cleared by worker threads.
+			 *
+			 * Each call to work_func() takes ownership of a Batch structure and adds
+			 * any ranges to be set/cleared in the strings table to avoid all worker
+			 * threads bottlenecking on serialised access to the shared table.
+			 *
+			 * Batched changes are periodically flushed to the main strings table while
+			 * scanning and at the end of a search, or before any data is inserted or
+			 * erased to ensure that there are no mid-air collisions in the queue.
+			*/
+			struct Batch
+			{
+				ByteRangeSet ranges_to_set;
+				ByteRangeSet ranges_to_clear;
+				
+				int ttl; /**< Remaining number of times this batch can be locked
+				          *   before it must be flushed even if under threshold.
+				         */
+			};
+			
 		public:
 			StringPanel(wxWindow *parent, SharedDocumentPointer &document, DocumentCtrl *document_ctrl);
 			~StringPanel();
 			
 			virtual std::string name() const override;
-// 			virtual std::string label() const override;
-// 			virtual Shape shape() const override;
+			virtual std::string label() const override;
+			virtual Shape shape() const override;
 			
 			virtual void save_state(wxConfig *config) const override;
 			virtual void load_state(wxConfig *config) override;
@@ -72,7 +95,6 @@ namespace REHex {
 			
 			ByteRangeSet get_strings();
 			off_t get_clean_bytes();
-			size_t get_num_threads();
 			void set_encoding(const std::string &encoding_key);
 			void set_min_string_length(int min_string_length);
 			
@@ -85,6 +107,8 @@ namespace REHex {
 			static wxString get_item_string(StringPanelListCtrl *list_ctrl, int item_idx);
 			static wxString get_item_offset_and_string(StringPanelListCtrl *list_ctrl, int item_idx);
 			
+			bool search_pending() const;
+			
 		private:
 			SharedDocumentPointer document;
 			SafeWindowPointer<DocumentCtrl> document_ctrl;
@@ -109,33 +133,51 @@ namespace REHex {
 			ByteRangeSet strings;
 			bool update_needed;
 			
-			std::list<std::thread> threads;  /* List of threads created and not yet reaped. */
-			std::atomic<bool> threads_exit;  /* Threads should exit. */
+			RangeProcessor processor;
 			wxTimer timer;
 			
-			std::mutex pause_lock;              /* Mutex protecting access to this block of members: */
-			std::atomic<bool> threads_pause;    /* Running threads should enter paused state. */
-			unsigned int spawned_threads;       /* Number of threads created. */
-			unsigned int running_threads;       /* Number of threads not paused. */
-			std::condition_variable paused_cv;  /* Notifies pause_threads() that a thread has paused. */
-			std::condition_variable resume_cv;  /* Notifies paused threads that they should resume. */
-			ByteRangeSet dirty;                 /* Ranges which are dirty, but not yet ready to be processed. */
-			ByteRangeSet pending;               /* Ranges waiting to be processed. */
-			ByteRangeSet working;               /* Ranges currently being processed. */
+			bool m_search_pending; /**< Ready to scan file whenever tool is visible. */
+			bool m_search_running; /**< Search is running in the background. */
+			
 			off_t search_base;
 			
-			void mark_dirty(off_t offset, off_t length);
 			void mark_dirty_pad(off_t offset, off_t length);
-			void mark_work_done(off_t offset, off_t length);
 			off_t sum_dirty_bytes();
 			off_t sum_clean_bytes();
 			
-			void thread_main();
-			void thread_flush(ByteRangeSet *set_ranges, ByteRangeSet *clear_ranges, bool force);
-			void start_threads();
-			void stop_threads();
-			void pause_threads();
-			void resume_threads();
+			void start_search();
+			void suspend_search();
+			void stop_search();
+			
+			void restart_search();
+			
+			void work_func(off_t window_base, off_t window_length);
+			
+			std::mutex m_batch_mutex;        /**< Mutex for m_batch_queue. */
+			std::queue<Batch> m_batch_queue; /**< Queue of unlocked Batch objects. */
+			
+			/**
+			 * @brief Lock a Batch from the queue or allocate a new one.
+			*/
+			Batch next_batch();
+			
+			/**
+			 * @brief Return a Batch to the queue.
+			*/
+			void release_batch(Batch &&batch);
+			
+			/**
+			 * @brief Flush changes from a Batch to the strings table.
+			 *
+			 * @param batch  Batch object.
+			 * @param force  Force flush even if below required number of changes.
+			*/
+			void flush_batch(Batch *batch, bool force);
+			
+			/**
+			 * @brief Flush changes from all Batch objects in the queue.
+			*/
+			void flush_all_batches();
 			
 			void do_export(wxString (*get_item_func)(StringPanelListCtrl*, int));
 			
