@@ -1,5 +1,5 @@
 /* Reverse Engineer's Hex Editor
- * Copyright (C) 2021 Daniel Collins <solemnwarning@solemnwarning.net>
+ * Copyright (C) 2021-2025 Daniel Collins <solemnwarning@solemnwarning.net>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published by
@@ -97,6 +97,16 @@ std::string REHex::VirtualMappingList::name() const
 	return "VirtualMappingList";
 }
 
+std::string REHex::VirtualMappingList::label() const
+{
+	return "Virtual sections";
+}
+
+REHex::ToolPanel::Shape REHex::VirtualMappingList::shape() const
+{
+	return ToolPanel::TPS_TALL;
+}
+
 void REHex::VirtualMappingList::save_state(wxConfig *config) const
 {
 	/* No state to save. */
