@@ -21,45 +21,12 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "testutil.hpp"
 #include "../src/IntelHexExport.hpp"
 #include "../src/SharedDocumentPointer.hpp"
 
 using namespace REHex;
 
-class TempFilename
-{
-	public:
-		char tmpfile[L_tmpnam];
-		
-		TempFilename()
-		{
-			if(tmpnam(tmpfile) == NULL)
-			{
-				throw std::runtime_error("Cannot generate temporary file name");
-			}
-			
-#ifdef _WIN32
-			/* > Note than when a file name is pre-pended with a backslash and no path
-			 * > information, such as \fname21, this indicates that the name is valid
-			 * > for the current working directory.
-			 * - MSDN
-			 *
-			 * Sure, that makes total sense.
-			*/
-			if(tmpfile[0] == '\\' && strchr((tmpfile + 1), '\\') == NULL)
-			{
-				/* Remove the leading slash. */
-				memmove(tmpfile, tmpfile + 1, strlen(tmpfile) - 1);
-			}
-#endif
-		}
-		
-		~TempFilename()
-		{
-			unlink(tmpfile);
-		}
-};
-
 #define EXPECT_FILE(t) \
 { \
 	std::string content; \
